id stringlengths 64 64 | content stringlengths 500 100k | language stringclasses 29
values | path stringlengths 4 333 | repo stringlengths 5 116 | license stringclasses 15
values | size int64 500 100k | lines int64 26 8.06k | source stringclasses 1
value |
|---|---|---|---|---|---|---|---|---|
d50fa96968b719d8be0d94fd4eef076eec0594c54a21c54966b3fcecf5a77aae | # Smallest Integer
# I worked on this challenge by myself.
# smallest_integer is a method that takes an array of integers as its input
# and returns the smallest integer in the array
#
# +list_of_nums+ is an array of integers
# smallest_integer(list_of_nums) should return the smallest integer in +list_of_nums+
#
# If... | Ruby | week-4/smallest-integer/my_solution.rb | jonwhuang/phase-0 | mit | 753 | 35 | codeparrot/github-code |
c63109636664c7711d25d76201d34e3364e1997510232ed411fd7412ac7f16d0 | package com.mvas.webproxy.portals;
import com.mvas.webproxy.DeviceConnectionInfo;
import com.mvas.webproxy.RequestData;
import com.mvas.webproxy.WebServer;
import com.mvas.webproxy.config.PortalConfiguration;
import org.apache.commons.io.IOUtils;
import org.json.JSONException;
import org.json.JSONObject;
import org.s... | Java | src/main/java/com/mvas/webproxy/portals/StalkerRequestHandler.java | mvasilchuk/webproxy | mit | 9,322 | 258 | codeparrot/github-code |
3cddb7e315463f905c1f17425cc3bd1d22eff26cf4d70e09b6a861fc1510f995 | /**
* This program and the accompanying materials
* are made available under the terms of the License
* which accompanies this distribution in the file LICENSE.txt
*/
package com.archimatetool.editor.actions;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import... | Java | com.archimatetool.editor/src/com/archimatetool/editor/actions/CheckForNewVersionAction.java | archimatetool/archi | mit | 4,513 | 129 | codeparrot/github-code |
523fbb3a9d58f735a71bc221e3e25a1fa2e2742fe6565ab9a42802f8bcee61cb | using System;
using System.Collections.Generic;
using EspaceClient.BackOffice.Domaine.Results;
using EspaceClient.BackOffice.Silverlight.Business.Depots;
using EspaceClient.BackOffice.Silverlight.Business.Interfaces;
using EspaceClient.BackOffice.Silverlight.Infrastructure.Services;
using EspaceClient.FrontOffice.Domai... | C# | EC/espace-client-dot-net/EspaceClient.BackOffice.Silverlight.Data/Depots/DepotPieceJointe.cs | apo-j/Projects_Working | mit | 5,615 | 139 | codeparrot/github-code |
d6853dc1744a83024ddbb9007951b27bdaed67d761faab02936064d93fdecf4c | from io import BytesIO
from django import forms
from django.http import HttpResponse
from django.template import Context, Template
from braces.views import LoginRequiredMixin
from django.views.generic import DetailView, ListView
from django.views.decorators.http import require_http_methods
from django.contrib import... | Python | app/members/views.py | mooja/ssip3 | mit | 4,530 | 166 | codeparrot/github-code |
e147a15cc3fa032e539cb39bef124c1492d10c655b9967fc80187e8d366ac55a | <?php
namespace Pinq\Iterators\Generators;
use Pinq\Iterators\Standard\IIterator;
/**
* Implementation of the adapter iterator for Pinq\Iterators\IIterator using the generator
*
* @author Elliot Levin <elliotlevin@hotmail.com>
*/
class IIteratorAdapter extends Generator
{
/**
* @var IIterator
*/
... | PHP | Source/Iterators/Generators/IIteratorAdapter.php | TimeToogo/Pinq | mit | 671 | 34 | codeparrot/github-code |
87d0066ce6b64304ee42b55ba2fff5e2b5787ac8a9d6975671a20a857a153661 | M.profile("generators");
function* forOfBlockScope() {
let a = [1, 2, 3, 4, 5, 6, 7, 8];
let b = [10, 11, 12, 13, 14, 15, 16];
const funs = [];
for (const i of a) {
let j = 0;
funs.push(function* iter() {
yield `fo1: ${i} ${j++}`;
});
}
for (var i of a) {
var j = 0;
funs.push(func... | JavaScript | packages/core/test/samples/for-of-stmt/closures-in.js | awto/effectfuljs | mit | 4,231 | 199 | codeparrot/github-code |
2fde878179e854de56f52314fe3c304a726551428388599473b5ff35821c1116 | <!DOCTYPE html>
<html>
<head>
<link href="css/awsdocs.css" rel="stylesheet" type="text/css">
<script type="text/javascript" src="js/jquery.min.js"></script>
<script type="text/javascript" src="js/awsdocs.min.js"></script>
<meta charset="utf-8">
</head>
<body>
<div id="content" style="padding: 10px 3... | HTML | AWS_CloudFormation_Template_Reference.docset/Contents/Resources/Documents/aws-resource-route53-hostedzone.html | pdhodgkinson/AWSCloudFormationTemplateReference-dash-docset | mit | 14,906 | 223 | codeparrot/github-code |
e53f40f24daf1da171df83230e5d43a4643716644580562c7cfa49f9fc46589e | <?php
namespace BigD\UbicacionBundle\Form\EventListener;
use Doctrine\ORM\EntityRepository;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\PropertyAcces... | PHP | src/BigD/UbicacionBundle/Form/EventListener/AddCityFieldSubscriber.php | matudelatower/BigD | mit | 3,120 | 93 | codeparrot/github-code |
01895520eb350660ab7e59a5805b5ba0937f70a5edc038120e22aac43f2ab6e8 | /*
* Webpack development server configuration
*
* This file is set up for serving the webpack-dev-server, which will watch for changes and recompile as required if
* the subfolder /webpack-dev-server/ is visited. Visiting the root will not automatically reload.
*/
'use strict';
import webpack from 'webpack';
impor... | JavaScript | client/webpack.config.js | RiddleMan/giant-privacy-spy | mit | 1,796 | 68 | codeparrot/github-code |
52e1b154d5df451f3068f264a8726e620c05e67084dd0925e2fd8dd88d4a63c7 | // This code will add an event listener to each anchor of the topbar after being dynamically replaced by "interchange"
$("body").on("click", function(event){
// If the active element is one of the topbar's links continues
if($(event.target).hasClass("topbarLink")) {
// The parent li element of the current acti... | JavaScript | js/commons/activateCurrentLink.js | joseAyudarte91/aterbe_web_project | mit | 1,381 | 31 | codeparrot/github-code |
2124150eddaa34d411944d9c176f92e939163a969004e84f807fb5c495db84e5 | /*
* Created on 24/02/2014
*
*/
package net.rlviana.pricegrabber.model.entity.common;
import net.rlviana.pricegrabber.context.JPAPersistenceContext;
import net.rlviana.pricegrabber.model.entity.AbstractReadOnlyEntityTest;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.slf4j.Logger;
import org.sl... | Java | pricegrabber-model/src/test/java/net/rlviana/pricegrabber/model/entity/common/CurrencyTest.java | rlviana/pricegrabber-app | mit | 1,712 | 66 | codeparrot/github-code |
17532154882413cc9563c7a34939b51af920e4cec2dcbf85a8085a1eae9a062a | #include "utfgrid_encode.h"
#include <unordered_map>
#include <glog/logging.h>
#include <jsoncpp/json/value.h>
#include <mapnik/unicode.hpp>
struct value_to_json_visitor {
Json::Value operator() (const mapnik::value_null& val) {return Json::Value();}
Json::Value operator() (const mapnik::value_bool& val) {re... | C++ | src/utfgrid_encode.cpp | sputnik-maps/maps-express | mit | 4,103 | 114 | codeparrot/github-code |
7d0b13b8b62985a45cd125271ce52bbee4246a1bee33cb9a287113965eaf60ba | package me.moodcat.api;
import java.util.Arrays;
import java.util.List;
import java.util.Locale;
import java.util.stream.Collectors;
import lombok.Getter;
import me.moodcat.database.embeddables.VAVector;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
/**
* A... | Java | src/main/java/me/moodcat/api/Mood.java | MoodCat/MoodCat.me-Core | mit | 3,192 | 108 | codeparrot/github-code |
b4a6492c3348c1c1aa62948fb6f7ca6585ea492a62f8f6ef7cf3a673329037da |
import time
import multiprocessing
from flask import Flask
app = Flask(__name__)
backProc = None
def testFun():
print('Starting')
while True:
time.sleep(3)
print('looping')
time.sleep(3)
print('3 Seconds Later')
@app.route('/')
def root():
return 'Started a background pr... | Python | test.py | wikomega/wikodemo | mit | 1,073 | 53 | codeparrot/github-code |
7641f2d0f083228ef8bab6c20b7a42262576179e3e9962c6e899172628fe00ae | var textDivTopIndex = -1;
/**
* Creates a div that contains a textfiled, a plus and a minus button
* @param {String | undefined} textContent string to be added to the given new textField as value
* @returns new div
*/
function createTextDiv( textContent ) {
textDivTopIndex++;
var newTextDiv = document.create... | JavaScript | DOMBuilder/InputElementBuilder.js | amdor/skyscraper_fes | mit | 2,501 | 60 | codeparrot/github-code |
580033beb43088ee547c40877674ecfcb11377fdadad49015ff8360b170b17ed | #pragma once
#include "ofMain.h"
#include "ofxOsc.h"
#include "VHPtriggerArea.h"
#include "ofxXmlSettings.h"
class ofApp : public ofBaseApp{
public:
void setup();
void update();
void draw();
void keyPressed(int key);
void keyReleased(int key);
void mouseMoved(int x, int y );
void mouseDragged(int x, ... | C | exploracion pruebas y juegos/backgroundSubtraction/src/ofApp.h | alg-a/herm3TICa | mit | 1,372 | 57 | codeparrot/github-code |
c439de7fae1d808d98e957f97c623a334c61efc36fd83983c5c3ead6ea1382c6 | 'use strict';
/**
* Stripe library
*
* @module core/lib/c_l_stripe
* @license MIT
* @copyright 2016 Chris Turnbull <https://github.com/christurnbull>
*/
module.exports = function(app, db, lib) {
return {
/**
* Donate
*/
donate: function(inObj, cb) {
var number, expiry, cvc, currency;
... | JavaScript | src/core/lib/c_l_stripePay.js | christurnbull/MEANr-api | mit | 2,154 | 80 | codeparrot/github-code |
54445bd696e3225e07168371e0e82c019eb17898e3bf12f31d4d25079572a4bd | /**
* Module dependencies
*/
const express = require('express');
const cluster = require('cluster');
const numCPUs = require('os').cpus().length;
const compression = require('compression');
const helmet = require('helmet');
const hpp = require('hpp');
const config = require('./config');
const api = require('./api');
... | JavaScript | index.js | pazguille/haysubte | mit | 1,517 | 88 | codeparrot/github-code |
cdbdc1eb99eaec4d79d7a996aa17c708c137e7a6eed05c655771e119078424b7 | #!/bin/sh
set -e
echo "mkdir -p ${CONFIGURATION_BUILD_DIR}/${FRAMEWORKS_FOLDER_PATH}"
mkdir -p "${CONFIGURATION_BUILD_DIR}/${FRAMEWORKS_FOLDER_PATH}"
SWIFT_STDLIB_PATH="${DT_TOOLCHAIN_DIR}/usr/lib/swift/${PLATFORM_NAME}"
install_framework()
{
if [ -r "${BUILT_PRODUCTS_DIR}/$1" ]; then
local source="${BUILT_PRO... | Shell | Example/Pods/Target Support Files/Pods-SwiftBus Watch Example Extension/Pods-SwiftBus Watch Example Extension-frameworks.sh | victorwon/SwiftBus | mit | 3,785 | 94 | codeparrot/github-code |
bb5fbed95d64fce16ec983241c9e14465b7db7a3708bfd1d9d3b0eafd385e164 | #include <vector>
#include <iostream>
struct point
{
double x;
double y;
};
int main()
{
// Generate a lot of uniformly distributed 2d points in the range -1,-1 to +1,+1.
enum { numXSamples = 10000 };
enum { numYSamples = 10000 };
std::vector<point> points;
points.reserve(numXSamples * numYSamples);
for(int x... | C++ | libraries/wasm-jit/Test/Benchmark/Benchmark.cpp | EOSIO/eos | mit | 944 | 43 | codeparrot/github-code |
aab911b10eca42beb7166b389aa4361ec2d1cc827860b1b9527323f4a4574fbf | using System;
using System.Drawing;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Forms;
using System.Windows.Input;
using MahApps.Metro.Controls;
using NHotkey;
using NHotkey.Wpf;
using QuickHelper.ViewModels;
using QuickHelper.Windows;
using Application = System.Windows.Application;
using... | C# | QuickHelper/MainWindow.xaml.cs | aburok/quick-helper | mit | 3,760 | 131 | codeparrot/github-code |
2f0af5d28e335b046b79ca737f7f0d2740b6db6f50675e41d77772f34ab7bdad | package fs.command;
import fs.App;
import fs.Disk;
import fs.util.FileUtils;
import java.util.Arrays;
/**
*
* @author José Andrés García Sáenz <jags9415@gmail.com>
*/
public class CreateFileCommand extends Command {
public final static String COMMAND = "mkfile";
@Override
public void execute(Str... | Java | src/fs/command/CreateFileCommand.java | leomv09/FileSystem | mit | 1,243 | 56 | codeparrot/github-code |
9c0a7a7f932a050560e18e7e12ab44d68a2d64fed3bfb19bea42b75dced5e9bb | import { A, O } from 'b-o-a';
import { State } from '../types/state';
import currentPage$ from '../props/current-page';
import signIn$ from '../props/sign-in';
import spots$ from '../props/spots';
import spotForm$ from '../props/spot-form';
import stampRallies$ from '../props/stamp-rallies';
import stampRally$ from '... | TypeScript | src/props/index.ts | bouzuya/rally-rxjs | mit | 1,793 | 77 | codeparrot/github-code |
cd1b5534fc55fcb38457fc951bf0ad01b64853897df69be0eef5a097d2a0812a | // Copyright (c) 2009-2010 Satoshi Nakamoto
// Copyright (c) 2009-2012 The Bitcoin developers
// Copyright (c) 2011-2012 Litecoin Developers
// Copyright (c) 2013-2013 Bluecoin Developers
// Distributed under the MIT/X11 software license, see the accompanying
// file COPYING or http://www.opensource.o... | C++ | src/netbase.cpp | dallen6/bluecoin | mit | 32,522 | 1,166 | codeparrot/github-code |
8483b3101415c56b77f99f047f16bcc72d655961a12dc114a0d6f3b7568d3f3d | <!DOCTYPE html>
<!--[if lt IE 7 ]><html class="ie ie6" lang="en"> <![endif]-->
<!--[if IE 7 ]><html class="ie ie7" lang="en"> <![endif]-->
<!--[if IE 8 ]><html class="ie ie8" lang="en"> <![endif]-->
<!--[if (gte IE 9)|!(IE)]><!-->
<html lang="en" xmlns="http://www.w3.org/1999/html"> <!--<![endif]-->
<head>
<!-- Basic... | HTML | bower_components/font-awesome/src/3.2.1/icon/laptop/index.html | MooseFrankenstein/Bootstarlight | mit | 10,109 | 209 | codeparrot/github-code |
f7da7faadb6cb9bb6a1dee083adc25f2fbf846ec928890c24f0c62f6a4392ab2 | 'use strict';
/*
* * angular-socialshare v0.0.2
* * ♡ CopyHeart 2014 by Dayanand Prabhu http://djds4rce.github.io
* * Copying is an act of love. Please copy.
* */
angular.module('djds4rce.angular-socialshare', [])
.factory('$FB', ['$window', function($window) {
return {
init: function(fbId) {
... | JavaScript | public/scripts/libs/bower/angular-socialshare.js | khiettran/gofar | mit | 14,489 | 409 | codeparrot/github-code |
8f67f8d90e8c373767127744c3fcedf0dea85acf252e44ff0e536c1263342c8f | using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using System.Xml.Linq;
using System.Globalization;
namespace DevTreks.Extensions
{
/// <summary>
///Purpose: Serialize and deserialize a food nutrition cost object.
/// This calculator is u... | C# | src/DevTreks.Extensions/MN1/Statistics/MNC1Calculator.cs | kpboyle1/devtreks | mit | 8,299 | 199 | codeparrot/github-code |
7b92b3f6db02e42644171c4efbc418c7204a250b1398d26a8041af462d72dde2 | angular.module('myApp.toDoController', []).
controller('ToDoCtrl', ['$scope', '$state', '$http', '$route', function ($scope, $state, $http, $route) {
$scope.$state = $state;
$scope.addToDo = function() {
// Just in case...
if ($scope.toDoList.length > 50) {
alert("Exceeded to-do limit!!!");
retu... | JavaScript | app/to-do/toDoController.js | The-Lando-System/personal-website | mit | 2,424 | 121 | codeparrot/github-code |
8d76850d92387a0f0d2daa4165f2bd6ce8c8d85c09ff28e12b1097060cb11e20 | // Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
package com.azure.data.cosmos.internal.query;
import com.azure.data.cosmos.BadRequestException;
import com.azure.data.cosmos.BridgeInternal;
import com.azure.data.cosmos.CommonsBridgeInternal;
import com.azure.data.cosmos.i... | Java | sdk/cosmos/microsoft-azure-cosmos/src/main/java/com/azure/data/cosmos/internal/query/DocumentQueryExecutionContextFactory.java | navalev/azure-sdk-for-java | mit | 11,381 | 226 | codeparrot/github-code |
d9985e7ae48ec35e5854a47a9f06f2077e373fdfae10a3aa8f3e60c3bf860604 | import sys
MAX_NUM_STORED_LINES = 200
MAX_NUM_LINES = 10
LINEWIDTH = 80
class CmdText(object):
"""
Represents a command line text device. Text is split into lines
corresponding to the linewidth of the device.
"""
def __init__(self):
"""
Construct empty object.
"""
s... | Python | django-web/webcmd/cmdtext.py | t-mertz/slurmCompanion | mit | 4,609 | 184 | codeparrot/github-code |
4a17033a94846cfd477cb37af01b700e78b8d252c7145db10f747d487addfd83 | using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using FlatRedBall;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
namespace Anfloga.Rendering
{
public class BloomRenderer : IEffectsRenderer
{
public int Height { get; set; }
public i... | C# | Anfloga/Anfloga/Rendering/BloomRenderer.cs | vchelaru/Anfloga | mit | 3,160 | 87 | codeparrot/github-code |
0d842e156bf3382345c518d172a98adc060191ea989c5dfa37a28da0c2fef096 | #[macro_export]
macro_rules! punctuator {
($lexer: ident, $p: ident) => ({
$lexer.iter.next();
Ok(Token::Punctuator(Punctuator::$p, $lexer.lo, $lexer.lo + 1))
})
}
// Advance iter and hi position if pattern match
#[macro_export]
macro_rules! take {
($lexer: ident, $($p: pat)|*) => (
match $le... | Rust | graphql-language/src/lexer/macros.rs | cksac/graphql-rs | mit | 1,813 | 94 | codeparrot/github-code |
936041ab86ec8da0c6eca2ecf887ab01981d2712fc889a2939bb2387c6ef3709 | /* from optimizations/bfs/topology-atomic.cu */
#define BFS_VARIANT "topology-atomic"
#define WORKPERTHREAD 1
#define VERTICALWORKPERTHREAD 12 // max value, see relax.
#define BLKSIZE 1024
#define BANKSIZE BLKSIZE
__global__
void initialize(foru *dist, unsigned int *nv) {
unsigned int ii = blockIdx.x * blockDim.x +... | C | LoneStar/apps/bfs/BFS_ATOMIC/bfs_topo_atomic.h | Geof23/SESABench_II | mit | 5,764 | 185 | codeparrot/github-code |
aabe9e114e7f87d5e6cb3fd086fa5e388a03c5d7c720b3b3d66c0e32322d02b6 | #include <stdio.h>
#include <stdint.h>
#include <ibcrypt/chacha.h>
#include <ibcrypt/rand.h>
#include <ibcrypt/sha256.h>
#include <ibcrypt/zfree.h>
#include <libibur/util.h>
#include <libibur/endian.h>
#include "datafile.h"
#include "../util/log.h"
int write_datafile(char *path, void *arg, void *data, struct forma... | C | client/datafile.c | iburinoc/ibchat | mit | 5,238 | 258 | codeparrot/github-code |
ac214dbef68452c5daa814b0d98d276b661a1ce07794c339ffd8efb58bc6b4e6 | package com.avsystem.scex.util.function;
import org.apache.commons.codec.digest.HmacAlgorithms;
import org.apache.commons.codec.digest.HmacUtils;
import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.StringUtils;
import java.util.Collection;
public class StringUtilImpl implements StringU... | Java | scex-util/src/main/scala/com/avsystem/scex/util/function/StringUtilImpl.java | AVSystem/scex | mit | 5,283 | 179 | codeparrot/github-code |
31df29701a9edbddd55fae424c9c0c521a662aad260c6c86c27b307cdf416fb3 | <!doctype html>
<!--[if IE 9 ]><html class="ie9" lang="en"><![endif]-->
<!--[if (gt IE 9)|!(IE)]><!--><html lang="en"><!--<![endif]-->
<head>
<title>Flatastic - Checkout</title>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
<!... | HTML | project/flatastic_html/Main_v2.3/html/checkout.html | TroyerPro/proyectoFinal | mit | 76,232 | 1,438 | codeparrot/github-code |
689ee5a9d86f6d1bfa922bb308cb93dc5ea017aa61c0d8074e6540d0b27089e1 | package work.notech.poker.room;
import work.notech.poker.logic.Cards;
import java.util.List;
public class GameRoom {
private Integer roomIds;
private List<Integer> clientIds;
private Cards cards;
public Integer getRoomIds() {
return roomIds;
}
public void setRoomIds(Integer roomIds)... | Java | code/poker-server/src/main/java/work/notech/poker/room/GameRoom.java | wangzhaoming/Poker | mit | 671 | 36 | codeparrot/github-code |
b1d06f432e36ce9aad6b48b775ec41bf28cbf1c221ba3b2653d7141ac0798937 | // Take well-formed json from a sensu check result a context rich html document to be mail to
// one or more addresses.
//
// LICENSE:
// Copyright 2016 Yieldbot. <devops@yieldbot.com>
// Released under the MIT License; see LICENSE
// for details.
package main
import (
"bytes"
"fmt"
"github.com/codegangsta/c... | GO | cmd/handler-mailer/main.go | yieldbot/sensumailer | mit | 2,623 | 110 | codeparrot/github-code |
018de59bd245805b4fb001865d51450e0bd385a7e70c1ce894d1d90635143b1a | <?php
/*
* This file is part of the Symfony package.
*
* (c) Fabien Potencier <fabien@symfony.com>
*
* For the full copyright and license information, please view the LICENSE
* file that was distributed with this source code.
*/
namespace Symfony\Component\HttpKernel\DataCollector;
use Symfony\Component\HttpF... | PHP | src/Symfony/Component/HttpKernel/DataCollector/RequestDataCollector.php | ondrejmirtes/symfony | mit | 8,681 | 286 | codeparrot/github-code |
0f52af571f742f8e95b5d4240dcbd81e3c5698b543c0b5194e0ecc7c058e633e | package com.sunilson.pro4.activities;
import android.app.DatePickerDialog;
import android.app.TimePickerDialog;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.widget.CompoundButton;
i... | Java | Android App/app/src/main/java/com/sunilson/pro4/activities/AddLivetickerActivity.java | sunilson/My-Ticker-Android | mit | 11,353 | 308 | codeparrot/github-code |
704f8ca688b94f96e13eed051c20db78c024695900bf8594315cb92947683658 | import nextConnect from 'next-connect'
import auth from '../../middleware/auth'
import { deleteUser, updateUserByUsername } from '../../lib/db'
const handler = nextConnect()
handler
.use(auth)
.get((req, res) => {
// You do not generally want to return the whole user object
// because it may contain sensi... | JavaScript | examples/with-passport-and-next-connect/pages/api/user.js | flybayer/next.js | mit | 1,087 | 37 | codeparrot/github-code |
15b2c8dd3e573a71c837d64b2194cd2456c44014b1584b8f6ad13e918b0af40b | ;(function() {
angular.module('app.core')
.config(config);
/* @ngInject */
function config($stateProvider, $locationProvider, $urlRouterProvider) {
$stateProvider
/**
* @name landing
* @type {route}
* @description First page for incoming users, and for default routing
... | JavaScript | src/client/app/core/config/routes.config.js | radiant-persimmons/mockr | mit | 3,748 | 150 | codeparrot/github-code |
5f5fae49bbb02fa4bc9054e3d7e9d58aa5cb50dd0dc3e2f29c4e5d8b6ba3c7ea | using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Sockets;
namespace CommonTypes
{
/// <summary>
/// BrokerSite hides the replication in a site making the calls transparent.
/// </summary>
[Serializable]
public class BrokerSiteFrontEnd : IBroker
{
... | C# | SESDAD/CommonTypes/BrokerSiteFrontEnd.cs | pasadinhas/dad-project | mit | 4,966 | 177 | codeparrot/github-code |
f0360205d0e38b1e0ab1576e1e5bd0db47be49ddfb6807054a181ae439dd5ee4 | import lowerCaseFirst from 'lower-case-first';
import {handles} from 'marty';
import Override from 'override-decorator';
function addHandlers(ResourceStore) {
const {constantMappings} = this;
return class ResourceStoreWithHandlers extends ResourceStore {
@Override
@handles(constantMappings.getMany.done)
... | JavaScript | src/store.js | taion/flux-resource-marty | mit | 3,040 | 130 | codeparrot/github-code |
d63c15971435fdb5bdfbda342e8fbfd2f333b12924330b194a6e8a1c11be84e6 | <?php
namespace proyecto\backendBundle\Entity;
/**
* Entidad Respuesta
* @author Javier Burguillo Sánchez
*/
class Respuesta
{
/**
* @var integer
*/
private $id;
/**
* @var string
*/
private $respuesta;
/**
* @var \proyecto\backendBundle\Entity\Subpregunta
*/
... | PHP | src/proyecto/backendBundle/Entity/Respuesta.php | jburgui/proyecto2.0 | mit | 2,023 | 111 | codeparrot/github-code |
d09b2b1a28c9272e11899d2774cfbd713d44801e35b397a1825403ca9e761251 | /*
* This file is part of Sponge, licensed under the MIT License (MIT).
*
* Copyright (c) SpongePowered <https://www.spongepowered.org>
* Copyright (c) contributors
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Softwar... | Java | src/main/java/org/spongepowered/common/mixin/core/network/NetworkManagerMixin.java | SpongePowered/SpongeCommon | mit | 3,754 | 98 | codeparrot/github-code |
169e697bad40996df661219b0d4e58fe68cb3f0e1b2f250f268b400ffcca3a2b | function solve(message) {
let tagValidator = /^<message((?:\s+[a-z]+="[A-Za-z0-9 .]+"\s*?)*)>((?:.|\n)+?)<\/message>$/;
let tokens = tagValidator.exec(message);
if (!tokens) {
console.log("Invalid message format");
return;
}
let [match, attributes, body] = tokens;
let attribute... | JavaScript | JS Core/JS Fundamentals/Exams/03. XML Messenger.js | kalinmarkov/SoftUni | mit | 1,486 | 41 | codeparrot/github-code |
b8886f5c698caebbd0677fa0a18e344fae5995b395a2b16123b89866eaefa706 | <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<!-- NewPage -->
<html lang="en">
<head>
<title>SendMessage</title>
<link rel="stylesheet" type="text/css" href="../../stylesheet.css" title="Style">
</head>
<body>
<script type="text/javascript"><!--
if (location... | HTML | html/doc/nxt/http/SendMessage.html | stevedoe/nxt-client | mit | 5,534 | 185 | codeparrot/github-code |
404cc4ea0815f2e9217a0ac3bedff428751913aa154290524fdf79094f3e4fa8 | 'use strict';
const path = require('path');
const jwt = require('jsonwebtoken');
const AuthConfig = require(path.resolve('./config')).Auth;
const jwtSecret = AuthConfig.jwt.secret;
const tokenExpirePeriod = AuthConfig.jwt.tokenExpirePeriod;
function generateToken(payLoad) {
const isObject = (typeof payLoad === ... | JavaScript | app/lib/token.js | shivarajnaidu/uv-token-based-auth-with-nodejs-passportjs-mysql | mit | 1,542 | 56 | codeparrot/github-code |
2cac79912118bbb4bc77b083ffb6ef24ff663aec9b532fe8a45e6c914301aa6e | <?php
namespace AppBundle\Form;
use AppBundle\AppBundle;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
class ProductType extends AbstractType
{
/**
* {@inherit... | PHP | src/AppBundle/Form/ProductType.php | Bunkermaster/exosymfony | mit | 885 | 45 | codeparrot/github-code |
bb7da948ab456c8350e6f0bcb32cfc55471f8f17698d286f63af555e8b1f557f | #!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from conans.model import Generator
from conans.client.generators import VisualStudioGenerator
from xml.dom import minidom
from conans.util.files import load
class VisualStudioMultiGenerator(Generator):
template = """<?xml version="1.0" encoding="utf-8"?>
<P... | Python | conans/client/generators/visualstudio_multi.py | lasote/conan | mit | 2,436 | 64 | codeparrot/github-code |
3ff34173cf906f4b1579338ef61e08c2c67cfcdd8620f48cc4a3729c96168f41 | <?php
defined('BASEPATH') OR exit('No direct script access allowed');
class M_slider extends Main_model {
function __construct() {
parent::__construct();
$this->table = array(
'name' => 'tbl_slider',
'coloumn' => array(
'slider_id' => ar... | PHP | application/modules/webadmin/models/M_slider.php | dwivivagoal/KuizMilioner | mit | 2,465 | 59 | codeparrot/github-code |
6ed8317235cae253cb0964f9b10fdeea1ce8d865885abd08b1ad5ca5be4792a6 | package org.katlas.JavaKh.rows;
import org.katlas.JavaKh.utils.RedBlackIntegerTree;
public class RedBlackIntegerMap<F> extends RedBlackIntegerTree<F> implements MatrixRow<F> {
/**
*
*/
private static final long serialVersionUID = 5885667469881867107L;
public void compact() {
}
public voi... | Java | src/KnotTheory/JavaKh-v2/src/org/katlas/JavaKh/rows/RedBlackIntegerMap.java | craigfreilly/masters-project-submission | mit | 518 | 32 | codeparrot/github-code |
dd240a3639b928743f514a3e59c3c43ddc932a4770d710de9f656f8fcf6a649f | <?php
/**
* Created by PhpStorm.
* User: jmannion
* Date: 04/08/14
* Time: 22:17
*/
namespace JamesMannion\ForumBundle\Form\User;
use Symfony\Component\Form\FormBuilderInterface;
use JamesMannion\ForumBundle\Constants\Label;
use JamesMannion\ForumBundle\Constants\Button;
use JamesMannion\ForumBundle\Constants\Va... | PHP | src/JamesMannion/ForumBundle/Form/User/UserCreateForm.php | mannion007/JamesMannionForum | mit | 3,204 | 110 | codeparrot/github-code |
f937b97039328346155477705e9e27be52438616058155ef083fd6766587f604 | /**
* @file main.c
* @brief Main routine
*
* @section License
*
* Copyright (C) 2010-2015 Oryx Embedded SARL. All rights reserved.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; eit... | C | Project/LPC1549_Keil/CycloneTCP_SSL_Crypto_Open_1_6_4/demo/st/stm32f4_discovery/smtp_client_demo/src/main.c | miragecentury/M2_SE_RTOS_Project | mit | 12,503 | 505 | codeparrot/github-code |
25d9d0a282ef60a7d3633d8ca2269ef17a3b19f0aff8694e70472469b0bf4c6c | /*! Slidebox.JS - v1.0 - 2013-11-30
* http://github.com/trevanhetzel/slidebox
*
* Copyright (c) 2013 Trevan Hetzel <trevan.co>;
* Licensed under the MIT license */
slidebox = function (params) {
// Carousel
carousel = function () {
var $carousel = $(params.container).children(".carousel"),
... | JavaScript | slidebox.js | trevanhetzel/slidebox | mit | 3,369 | 120 | codeparrot/github-code |
4acc89512aff1fa34fbdf4e21e9663803d68d223e1365bbe49464616e89cf714 | import React from 'react'
import PropTypes from 'prop-types'
import VelocityTrimControls from './VelocityTrimControls'
import Instrument from '../../images/Instrument'
import styles from '../../styles/velocityTrim'
import { trimShape } from '../../reducers/velocityTrim'
const handleKeyDown = (event, item, bank, userCh... | JavaScript | src/components/trims/VelocityTrim.js | dkadrios/zendrum-stompblock-client | mit | 2,066 | 86 | codeparrot/github-code |
66726c2d9f4a89359a8c8abe68eb66c560c8ad05b12eb813fd2c4893492e68ca | /*! HTML5 Boilerplate v5.2.0 | MIT License | https://html5boilerplate.com/ */
/*
* What follows is the result of much research on cross-browser styling.
* Credit left inline and big thanks to Nicolas Gallagher, Jonathan Neal,
* Kroc Camen, and the H5BP dev community and team.
*/
/* ===============================... | CSS | css/main.css | Simplon-Roubaix/ChallengeDimTeam | mit | 7,136 | 354 | codeparrot/github-code |
e1612191f38c1d40769f52914d7ad900d710de5a1762d2275a146f9c1e548ceb | #include <assert.h>
#include <SDL2/SDL.h>
#include <SDL2/SDL_ttf.h>
#include <video/gl.h>
#include <xxhash.h>
#include <memtrack.h>
#include "base/stack.h"
#include "core/common.h"
#include "base/math_ext.h"
#include "core/asset.h"
#include "core/configs.h"
#include "core/frame.h"
#include "core/logerr.h"
#include <c... | C | neon/src/core/application.c | m1nuz/neon-core | mit | 3,306 | 150 | codeparrot/github-code |
3fc00e1c55ece1f850ef70c5595802761b4031dc456d6201f455447fbecb05e4 | #pragma once
#include <QtCore/QPointer>
#include <QtWidgets/QTabWidget>
#include "backend/backend_requests_interface.h"
class BreakpointModel;
class PDIBackendRequests;
class DisassemblyView;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
clas... | C | src/prodbg/ui/code_views.h | emoon/ProDBG | mit | 1,505 | 55 | codeparrot/github-code |
92a72f122708580134ee7543e4e65976dd3055abc070ddb1fbce5195b8265432 | /**
* @fileoverview Rule to flag use of implied eval via setTimeout and setInterval
* @author James Allardice
*/
"use strict";
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const ast... | JavaScript | lib/rules/no-implied-eval.js | pvamshi/eslint | mit | 5,435 | 153 | codeparrot/github-code |
87b702ddc68eb116940d5455d21ea5514924a163a4ec9fd36157c566bb9948cb | /*
---------------------------------------------------------------------------
Open Asset Import Library (ASSIMP)
---------------------------------------------------------------------------
Copyright (c) 2006-2010, ASSIMP Development Team
All rights reserved.
Redistribution and use of this software in source and bin... | C++ | dependencies/assimp-2.0.863/tools/assimp_view/LogWindow.cpp | mtwilliams/mojo | mit | 6,958 | 255 | codeparrot/github-code |
a0d3c1f66003a52352bcc4d42e45758bc06fa198845e61f8280c200bcb522145 | ---
title: "Exploring UIAlertController"
date: 2014-09-07 00:00
link_to: swift
---
This morning, I was working on the [sample app](https://github.com/AshFurrow/Moya/issues/39) for [Moya](https://github.com/AshFurrow/Moya), a network abstraction framework that I’ve built on top of [Alamofire](https://github.com/Alamofi... | Markdown | source/blog/2014-09-07-uialertviewcontroller-example.markdown | yogoo/ashfurrow-blog | mit | 7,975 | 84 | codeparrot/github-code |
f2c4bd3f8b283d5345d96709c3d8282284e44ef3db5217140fd2a91dc4cabb8f | <?php
defined('BASEPATH') OR exit('No direct script access allowed');
/**
* Library to generate items for Sortable.js
*/
class Sortable {
protected $CI;
protected $mItems;
protected $mPostName = 'sortable_ids';
public function __construct()
{
$this->CI =& get_instance();
$this->CI->load->library('parser')... | PHP | application/modules/admin/libraries/Sortable.php | jiji262/codeigniter_boilerplate | mit | 2,088 | 84 | codeparrot/github-code |
967ce524606deee5b41e5134699cfae391da3ef3fd3020dfabcd4eac4cb9417d | import NodeFunction from '../core/NodeFunction.js';
import NodeFunctionInput from '../core/NodeFunctionInput.js';
const declarationRegexp = /^\s*(highp|mediump|lowp)?\s*([a-z_0-9]+)\s*([a-z_0-9]+)?\s*\(([\s\S]*?)\)/i;
const propertiesRegexp = /[a-z_0-9]+/ig;
const pragmaMain = '#pragma main';
const parse = ( source ... | JavaScript | examples/jsm/renderers/nodes/parsers/GLSLNodeFunction.js | jpweeks/three.js | mit | 2,740 | 136 | codeparrot/github-code |
9526ad9c42da65ecb8984b7f4bd01f1b78744da474aa14940944d68533c7a270 | "use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = R... | JavaScript | src/app/app.component.js | mail2yugi/ProjectTodoList | mit | 1,606 | 34 | codeparrot/github-code |
11d9c61c3d4073f16b3f6e23fc7a9ae69d2c78ea642a6240d87f47c66b03e708 | package de.uni.bremen.stummk.psp.calculation;
import java.lang.reflect.InvocationTargetException;
import java.util.List;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.ecl... | Java | Source/de.uni.bremen.stummk.psp/src/de/uni/bremen/stummk/psp/calculation/EditorToolbarAction.java | stummk/psp-eclipse | mit | 5,479 | 139 | codeparrot/github-code |
f3e1dacc197a402527434c65aff3714a622eb9e978174adc11a80dbeb716894a | <?php
/* FOSUserBundle:Resetting:request_content.html.twig */
class __TwigTemplate_16fccc8b4081822ba4c49543c44f48b24850d6b4ad9846152c39968be5b4e7c7 extends Twig_Template
{
public function __construct(Twig_Environment $env)
{
parent::__construct($env);
$this->parent = false;
$this->blo... | PHP | app/cache/dev/twig/16/fc/cc8b4081822ba4c49543c44f48b24850d6b4ad9846152c39968be5b4e7c7.php | thecoons/thecoontube | mit | 2,146 | 65 | codeparrot/github-code |
8d922f7165ea6962c013f23fba8a4c2049d5a2641077eb332f55c98ebddfa867 | <!DOCTYPE html>
<html>
<head>
<meta charset="utf-8" />
<meta http-equiv="X-UA-Compatible" content="IE=edge" />
<title>アルゴリズム計算量入門 〜 ② - イノベーション エンジニアブログ</title>
<meta name="HandheldFriendly" content="True">
<meta name="MobileOptimized" content="320">
<meta name="apple-mobile-web-app-capable" c... | HTML | 2018/06/25/Introduction-of-Computational-Complexity-2.html | innovation-jp/innovation-jp.github.io | mit | 30,615 | 798 | codeparrot/github-code |
6bd4e33b6b6c5f33e035c175d2081c6fa73d12c661ec0c8f158af33d4ece1be2 | /*
* Copyright (c) 2014 The WebRTC project authors. All Rights Reserved.
*
* Use of this source code is governed by a BSD-style license
* that can be found in the LICENSE file in the root of the source
* tree. An additional intellectual property rights grant can be found
* in the file PATENTS. All contribut... | C | Boss2D/addon/_old/webrtc-qt5.11.2_for_boss/modules/audio_coding/neteq/tools/packet.h | koobonil/Boss2D | mit | 4,769 | 119 | codeparrot/github-code |
37272ab12087620ee218d00847752fb7e595cbced01843754d013a53f2fddb67 | #include "Renderer.h"
#include "Core/Windows/Window.h"
#include <Resources/ResourceCache.h>
namespace uut
{
UUT_MODULE_IMPLEMENT(Renderer)
{}
Renderer::Renderer()
: _screenSize(0)
{
}
Renderer::~Renderer()
{
}
//////////////////////////////////////////////////////////////////////////////
bool Renderer::... | C++ | UUT/Video/Renderer.cpp | kolyden/uut-engine | mit | 896 | 49 | codeparrot/github-code |
522705f24df14987d3064bb050fdeee1c2127249c2d5871c1f24dc6ccaff25de | package jnt.scimark2;
public class kernel
{
// each measurement returns approx Mflops
public static double measureFFT(int N, double mintime, Random R)
{
// initialize FFT data as complex (N real/img pairs)
double x[] = RandomVector(2*N, R);
double oldx[] = NewVectorCopy(x);
long cycles = 1;
... | Java | app/src/main/java/jnt/scimark2/kernel.java | BU-PCM-Testbed/ThermalProfiler | mit | 7,529 | 336 | codeparrot/github-code |
d552e33ef4c7004241bd7ebfb65d3d696ca8573557f7b6903945d84ddabf608a | 'use strict'
const reduce = Function.bind.call(Function.call, Array.prototype.reduce);
const isEnumerable = Function.bind.call(Function.call, Object.prototype.propertyIsEnumerable);
const concat = Function.bind.call(Function.call, Array.prototype.concat);
const keys = Reflect.ownKeys;
if (!Object.values) {
Object.v... | JavaScript | polifill.js | vitaliiznak/game-fluky_colors | mit | 1,634 | 52 | codeparrot/github-code |
7964e2734c1b160b84c7f70fdc1d25038e9f94f145600c74c12272337f010c47 | <?php
use History\Entities\Models\Company;
use History\Entities\Models\Question;
use History\Entities\Models\Request;
use History\Entities\Models\Threads\Comment;
use History\Entities\Models\Threads\Thread;
use History\Entities\Models\User;
use History\Entities\Models\Vote;
use League\FactoryMuffin\FactoryMuffin;
use ... | PHP | resources/factories/factories.php | madewithlove/why-cant-we-have-nice-things | mit | 3,327 | 106 | codeparrot/github-code |
e1f0fee2c5e85f672165e94e2fe4846936c4eb4f1959d4d1faf0d50916beda9d | /*
* optimization needed.
*/
struct ListNode {
int val;
struct ListNode *next;
};
#ifndef NULL
#define NULL ((struct ListNode *)0)
#endif
struct ListNode *detectCycle(struct ListNode *head)
{
if (!head || !head->next)
return(NULL);
if (head->next == head)
return(head);
struct ListNode *p1, *p2;
int has... | C | 142_linked_list_cycle_II.c | wuzhouhui/leetcode | mit | 866 | 72 | codeparrot/github-code |
9b550f7f358362d54cbffcb1af420e8f0fa04f92a3e2c4a27809025bf1a704a1 | package com.twitter.meil_mitu.twitter4holo.api.help;
import com.twitter.meil_mitu.twitter4holo.AbsGet;
import com.twitter.meil_mitu.twitter4holo.AbsOauth;
import com.twitter.meil_mitu.twitter4holo.ITwitterJsonConverter;
import com.twitter.meil_mitu.twitter4holo.OauthType;
import com.twitter.meil_mitu.twitter4holo.Resp... | Java | library/src/main/java/com/twitter/meil_mitu/twitter4holo/api/help/Tos.java | MeilCli/Twitter4Holo | mit | 1,064 | 37 | codeparrot/github-code |
46475a7706de9c035a5a5abb7934deb8604df1d80b87d32cecedcc157536a6cd | var STATE_START = 0;
var STATE_END = 1;
var STATE_GROUND = 2;
var STATE_FOREST = 3;
var STATE_WATER = 4;
function Cell(col, row) {
this.col = col;
this.row = row;
this.state = STATE_GROUND;
}
Cell.prototype.draw = function() {
stroke(66);
switch (this.state) {
case STATE_START:
Color.Material.light_green[5... | JavaScript | old/pathfinding/cell.js | dylandevalia/dylan.devalia.com | mit | 996 | 47 | codeparrot/github-code |
bcb87b6560f52bde87bcc872b8cf2517eb97d07b6085b096df3bd47c7ca43865 | var fs = require('fs');
var join = require('path').join;
var iconv = require('iconv-lite');
var debug = require('debug')('ip');
var util = require('util');
var EventEmitter = require('events').EventEmitter;
var thunkify = require('thunkify-wrap');
function IpUtil(ipFile, encoding, isLoad) {
if (typeof encoding === '... | JavaScript | index.js | leoner/iputil | mit | 7,101 | 346 | codeparrot/github-code |
aaa287f9ce09efdc27da5d85715e2073ef691079ba18f7e7bae0f3c77dd86103 | <HTML><HEAD>
<TITLE>Review for Vertical Limit (2000)</TITLE>
<LINK REL="STYLESHEET" TYPE="text/css" HREF="/ramr.css">
</HEAD>
<BODY BGCOLOR="#FFFFFF" TEXT="#000000">
<H1 ALIGN="CENTER" CLASS="title"><A HREF="/Title?0190865">Vertical Limit (2000)</A></H1><H3 ALIGN=CENTER>reviewed by<BR><A HREF="/ReviewsBy?Dennis+Sc... | HTML | data science/machine_learning_for_the_web/chapter_4/movie/27363.html | xianjunzhengbackup/code | mit | 8,298 | 128 | codeparrot/github-code |
190a1cce0ae9902bf58162aa8f498b77a2654527664082b5a544ebd8fd18a0a8 | using System;
using CommandLine;
using System.IO;
using Nancy.Hosting.Self;
using SeudoBuild.Core;
using SeudoBuild.Core.FileSystems;
using SeudoBuild.Pipeline;
using SeudoBuild.Net;
namespace SeudoBuild.Agent
{
class Program
{
private const string Header = @"
_ _ _ _ _
... | C# | SeudoBuild.Agent/Program.cs | mstevenson/SeudoBuild | mit | 10,530 | 290 | codeparrot/github-code |
06b99ec78e8ce503d658628488f50105cdc23b95a983fe7fce2d6ac1600adda1 | import { task } from 'gulp';
import { join } from 'path';
import { config } from '../utils/config';
import { sequenceTask } from '../utils/sequence-task';
import { readFileSync, writeFileSync } from 'fs';
const serve = require('browser-sync');
const webpack = require('webpack');
const webpackDevMiddelware = require(... | TypeScript | tools/gulp/tasks/serve.ts | zxhfighter/measure | mit | 2,904 | 97 | codeparrot/github-code |
1475460d8d6f053329cf5aee1ec43f3fc25b4a541f69af15f964bb591bb90dee | // TODO: write a test that ensures that Quagga.decodeSingle returns a Promise when it should
// TODO: write a test that tests the multiple: true decoding option, allowing for multiple barcodes in
// a single image to be returned.
// TODO: write a test that allows for locate: false and locator configs to be tested.
imp... | TypeScript | test/integration/integration.spec.ts | ericblade/quaggaJS | mit | 21,244 | 411 | codeparrot/github-code |
e9c4faddb59c964ad89563beddbed226eb63824ddcd45230215612982d3badca |
/*
Noble cread UART service example
This example uses Sandeep Mistry's noble library for node.js to
read and write from Bluetooth LE characteristics. It looks for a UART
characteristic based on a proprietary UART service by Nordic Semiconductor.
You can see this service implemented in Adafruit's BLEFriend library.
... | JavaScript | ble-uart.js | evejweinberg/SuperHeroAutoPilot | mit | 4,710 | 128 | codeparrot/github-code |
a453e54d8677ffdeeea64c02be62e56229a638f6a0c2443cd23eec96a3893230 | var db = require('mongoose');
var Log = require('log'), log = new Log('info');
var clienttracking = require('./clienttracking.js');
var mapreduce = require('./mapreduce.js');
var io = null;
exports.server = require('./adnoceserver.js');
exports.setDatabase = function(databaseConfiguration, callback) {
var port = ... | JavaScript | lib/adnoce.js | hkonitzer/adnoce | mit | 2,627 | 60 | codeparrot/github-code |
ee04f1b30ae8f0d033b7a333b8f5ce29a85ec67651e6dbe2b0b75ca026e1042c | import logging
import requests
from django.conf import settings
from django.contrib.sites.models import Site
from django.core.mail import EmailMultiAlternatives
from django.template.loader import get_template
from django.utils import timezone
from invitations.models import Invitation
logger = logging.getLogger('email... | Python | invitations/consumers.py | phildini/logtacts | mit | 1,739 | 50 | codeparrot/github-code |
4ca15983902ca8dee2edf03c7b5a5897dcb3e8eaaed2d0719412fc7bdf02e75a | /* **********************************************************************************************************
* The MIT License (MIT) *
* *
* Copyright (c) 2016 Hypermediasystems Ges. f. Software mbH *
* Web: http://www.hypermediasystems.de *
... | C# | hmssp/SP.gen/ServerSettings.cs | helmuttheis/hmsspx | mit | 4,781 | 106 | codeparrot/github-code |
fffd13699114290336c1a36e194ef9e52a788e130b67c302c0b6e70c5443e2b6 |
<!DOCTYPE html>
<html lang="english">
<head>
<link href='//fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,700,400italic' rel='stylesheet' type='text/css'>
<link rel="stylesheet" type="text/css" href="../theme/stylesheet/style.min.css">
<link rel="stylesheet" type="text/css" href="../theme/pygments/g... | HTML | drafts/ibm-bluemix.html | bassdeveloper/bassdeveloper.github.io | mit | 8,122 | 204 | codeparrot/github-code |
790b111b15d93725047d07d26be4a36e35ddf306c950d5cbb79ba41ad479cece | <rtl code>
var m = function (){
function T(){
this.a = [];
}
var r = new T();
var a = RTL$.makeArray(3, 0);
var dynamicInt = [];
var dynamicString = [];
var dynamicChar = [];
var dynamicByte = [];
var dynamicRecord = [];
var dynamicArrayOfStaticArrayInt = [];
var i = 0;
var s = '';
var byte = 0;
function assignDynami... | JavaScript | test/expected/eberon/dynamic_array.js | vladfolts/oberonjs | mit | 2,536 | 123 | codeparrot/github-code |
196d943a12aa99544a4f19a0ec3f851439c61664df066c0e132f5e85044558fa | var expect = require('chai').expect;
var assert = require('chai').assert;
var sinon = require('sinon');
var Config = require('../lib/config');
describe('config', function() {
describe('#constructor', function() {
it('creates a new object with the config defaults', function() {
sinon.spy(Config.prototyp... | JavaScript | test/config-test.js | philipwalton/ingen | mit | 1,739 | 81 | codeparrot/github-code |
c8ad75c9da9eb2976aa99f9a68c00aa5ae1745919f2b278bfd9ddc53d9fcc2c5 | using System.ComponentModel.Composition;
using System.IO;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using Microsoft.Azure;
using Microsoft.Azure.Management.Resources;
using Microsoft.Azure.Management.Resources.Models;
using Microsoft.Deployment.Common.ActionModel;
using Microsoft.Deploym... | C# | Source/Actions/Microsoft.Deployment.Actions.AzureCustom/HCL/CreateAzureMLWorkspace.cs | mayankon24/d-final | mit | 4,493 | 90 | codeparrot/github-code |
99e6063d860417cac22d66e7d5d199f7bd5d79aada8625ceafe1b8ea14845fcc | package wikimediaparser
import (
"fmt"
"github.com/golang/glog"
"strings"
)
// Node as it is emitted by the parser
// - contains a NodeType for clear identification
// - a string val Val
// - a list of named parameters which are actually Node Lists
// -a list of anonymous parameters, a Node list aga... | GO | node.go | octplane/wikiquote-parser | mit | 2,562 | 124 | codeparrot/github-code |
41a35cef534f91f32a2ce01cddd39a9d389f5c9e4c030fabd06f9d4a4fef9d41 | import Vue from 'vue';
import VueForm from 'vue-form';
Vue.use(VueForm, {
validators: {
'step': function(value, stepValue) {
return stepValue === `any` || Number(value) % Number(stepValue) === 0;
},
'data-exclusive-minimum': function(value, exclusiveMinimum) {
return Number(value) > Number(ex... | JavaScript | ui/plugins/vue-form.js | FloEdelmann/open-fixture-library | mit | 2,583 | 88 | codeparrot/github-code |
d74e57f03682519f7099b6bbe70f9a5708ca212ce067df756f76ed0fc782c9c4 |
var resources = require('jest'),
util = require('util'),
models = require('../../models'),
async = require('async'),
common = require('./../common'),
calc_thresh = require('../../tools/calc_thresh.js'),
GradeActionSuggestion = require('./grade_action_suggestion_resource.js'),
ActionSuggesti... | JavaScript | api/actions/GradeActionResource.js | saarsta/sheatufim | mit | 12,565 | 310 | codeparrot/github-code |
fa052000f42a5f854bd45acbdb6f5193f043d73de4deefccfb845d5edf851580 | using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UnityEngine;
using UnityEngine.EventSystems;
using UnityEngine.UI;
namespace CameraModifications
{
public class LookButton : MonoBehaviour
{
public bool isHead;
public H_Scene h_scene;
public H... | C# | CameraModifications/LookButton.cs | Eusth/Illusion-Plugins | mit | 6,019 | 176 | codeparrot/github-code |
e05f47e753785417b326630e061efb92bfd06627abbadf6f9408f0319664c131 | /**
* This Control enables to render a Scene with a Screen Space Ambient Occlusion (SSAO) effect.
*
* @namespace GIScene
* @class Control.SSAO
* @constructor
* @extends GIScene.Control
*/
GIScene.Control.SSAO = function() {
//inherit
GIScene.Control.call(this);
var scenePass;
var ssaoEffect;
var fxaaEf... | JavaScript | lib/GIScene/Control/SSAO.js | GIScience/GIScene.js | mit | 7,334 | 208 | codeparrot/github-code |
a3aeb4f1daed225a8c8df0e420ad10b9e4384fa15d12700408ee87e3284719ef | package com.cnpc.framework.utils;
import com.cnpc.framework.base.pojo.GenerateSetting;
import freemarker.template.Configuration;
import freemarker.template.DefaultObjectWrapper;
import freemarker.template.Template;
import freemarker.template.TemplateException;
import org.springframework.core.io.Resource;
import org.sp... | Java | Openparts-framework/src/main/java/com/cnpc/framework/utils/FreeMarkerUtil.java | XilongPei/Openparts | mit | 2,862 | 106 | codeparrot/github-code |
0787ff826b472e50de733c8d18e6e89d7e84a821cf4b52f89fa6ecae614ca7dd | <?php
/* @SRVDVServer/Registration/checkEmail.html.twig */
class __TwigTemplate_b7388a253fe83dce0c06be9794c45a140b6b7d51b0d7f4393b8bb6ea03bbb2f5 extends Twig_Template
{
public function __construct(Twig_Environment $env)
{
parent::__construct($env);
// line 1
$this->parent = $this->load... | PHP | app/cache/prod/twig/26/2661d52b18638f3c0557a97abe21ab4f663d0577907552ec42ba9fb1790acde1.php | youcefboukersi/serveurdevoeux | mit | 2,198 | 65 | codeparrot/github-code |
b44183d3978a23d04ad1a33816f0b4fdfe45024ed9e7ed1e4e73b4e76c5f4e9f | import * as b from "bobril";
import { IRouteWithNavDefinition } from "../../../../common/routing";
import { Anchor } from "../../../../common/Anchor";
import { Example } from "../../../../common/Example";
import { Col, Form, margin, Row } from "../../../../../index";
import { Code } from "../../../../common/Code";
impo... | TypeScript | example/documentation/content/forms/parts/FormsControls.tsx | keeema/bobrilstrap | mit | 10,919 | 253 | codeparrot/github-code |
4fc606da058b2c8fbb2a0ff12d790097ba2bff469d7ccaa9caf4b32ad944d0dd | package test.unit.hu.interconnect.hr.module.personaldata.vacations;
import static com.google.common.collect.Lists.newArrayList;
import static hu.interconnect.hr.backend.api.enumeration.KivetelnapTipus.MUNKANAP;
import static hu.interconnect.hr.backend.api.enumeration.KivetelnapTipus.PIHENONAP;
import static java.util.... | Java | hr2-java-parent/hr2-backend-impl/src/test/java/test/unit/hu/interconnect/hr/module/personaldata/vacations/SzabadsagokatOsszefuggoFelhasznaltSzabadnapReszletekkeKonvertaloTest.java | tornaia/hr2 | mit | 21,192 | 305 | codeparrot/github-code |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.